import {Component, OnDestroy, OnInit} from '@angular/core';
import {LecturerInfoService} from 'src/app/services/lecturer-info.service';
import {Router} from '@angular/router';
import {LecturerDataService} from 'src/app/services/lecturer-data.service';
import {LecturerViewService} from 'src/app/services/lecturer-view.service';
import {GridOptions} from 'ag-grid-community';
import {ViewClassesButtonComponent} from 'src/app/GridComponents/ViewClassesButton/view-classes-button.component';

@Component({
  selector: 'app-lecturer-dashboard',
  templateUrl: './lecturer-dashboard.component.html',
  styleUrls: ['./lecturer-dashboard.component.css']
})
export class LecturerDashboardComponent implements OnInit, OnDestroy {

  private isAlive = true;
  private lecturerId: String;
  public rowData: any;
  public gridOptions: GridOptions;
  public columnDefs = [
    {headerName: 'Class Code', field: 'classCode', sortable: true, lockPosition: true},
    {headerName: 'Class Name', field: 'classname', sortable: true, lockPosition: true},
    {headerName: 'Year', field: 'year', sortable: true, lockPosition: true},
    {headerName: 'View', field: '', cellRendererFramework: ViewClassesButtonComponent, lockPosition: true},
  ];

  constructor(private lecturerInfoService: LecturerInfoService,
              private lecturerDataService: LecturerDataService,
              private lecturerViewService: LecturerViewService,
              private router: Router) {
  }

  ngOnInit(): void {
    this.lecturerId = sessionStorage.getItem('username');
    this.gridOptions = {
      context: {componentParent: this}
    };
    this.rowData = this.lecturerInfoService.getLecturerClasses(this.lecturerId);
    this.lecturerViewService.changeToDashboard(true);
  }

  ngOnDestroy(): void {
    this.isAlive = false;
  }

  public goToPaperView(classCode: String) {
    this.lecturerDataService.classCode = classCode;
    this.lecturerViewService.changeToDashboard(false);
    this.router.navigate(['/paper-view']);
    this.ngOnDestroy();
  }
}
